==> netbeans_6.8.orig.tar.gz: netbeans-6.8/welcome/src/org/netbeans/modules/welcome/ui/BottomBar.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.modules.welcome.ui;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import javax.swing.JLabel;
import javax.swing.JPanel;
import org.netbeans.modules.welcome.content.Logo;

/**
 *
 * @author S. Aubrecht
 */
class BottomBar extends JPanel {

    public BottomBar() {
        super( new GridBagLayout() );
        setOpaque(false);
        
        add( Logo.createSunLogo(), new GridBagConstraints(0,0,1,1,0.0,0.0,
                GridBagConstraints.SOUTHWEST,GridBagConstraints.NONE,new Insets(0,12,0,5),0,0 ) );
        
        add( new JLabel(), new GridBagConstraints(1,0,1,1,1.0,0.0,
                GridBagConstraints.CENTER,GridBagConstraints.NONE,new Insets(0,0,0,0),0,0 ) );
        
        add( new ShowNextTime(), new GridBagConstraints(2,0,1,1,0.0,0.0,
                GridBagConstraints.SOUTH,GridBagConstraints.NONE,new Insets(0,0,0,0),0,0 ) );
        
        add( new JLabel(), new GridBagConstraints(3,0,1,1,1.0,0.0,
            GridBagConstraints.CENTER,GridBagConstraints.NONE,new Insets(0,0,0,0),0,0 ) );

        add( Logo.createJavaLogo(), new GridBagConstraints(4,0,1,1,0.0,0.0,
                GridBagConstraints.SOUTHEAST,GridBagConstraints.NONE,new Insets(0,5,0,12),0,0 ) );
    }

}

==> netbeans_7.0.1+dfsg1.orig.tar.gz: netbeans-7.0.1+dfsg1/welcome/src/org/netbeans/modules/welcome/ui/BottomBar.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.modules.welcome.ui;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import javax.swing.JLabel;
import javax.swing.JPanel;
import org.netbeans.modules.welcome.content.Logo;

/**
 *
 * @author S. Aubrecht
 */
class BottomBar extends JPanel {

    public BottomBar() {
        super( new GridBagLayout() );
        setOpaque(false);
        
        add( Logo.createOracleLogo(), new GridBagConstraints(0,0,1,1,0.0,0.0,
                GridBagConstraints.SOUTHWEST,GridBagConstraints.NONE,new Insets(0,35,0,5),0,0 ) );
        
        add( new JLabel(), new GridBagConstraints(1,0,1,1,1.0,0.0,
                GridBagConstraints.CENTER,GridBagConstraints.NONE,new Insets(0,0,0,0),0,0 ) );
        
        add( new ShowNextTime(), new GridBagConstraints(2,0,1,1,0.0,0.0,
                GridBagConstraints.SOUTH,GridBagConstraints.NONE,new Insets(0,0,0,0),0,0 ) );
        
        add( new JLabel(), new GridBagConstraints(3,0,1,1,1.0,0.0,
            GridBagConstraints.CENTER,GridBagConstraints.NONE,new Insets(0,0,0,0),0,0 ) );

        add( Logo.createJavaLogo(), new GridBagConstraints(4,0,1,1,0.0,0.0,
                GridBagConstraints.SOUTHEAST,GridBagConstraints.NONE,new Insets(0,5,0,35),0,0 ) );
    }

}
